Function get_timezone
fn get_timezone() -> Result<String, GetTimezoneError>
Get the current IANA time zone as a string.
See the module-level documentation for a usage example and more details about this function.
get_timezonefn get_timezone() -> Result<String, GetTimezoneError>
Get the current IANA time zone as a string.
See the module-level documentation for a usage example and more details about this function.